# **Flaskavel Framework**
**Your Web Development Laboratory**

<p align="center"><a href="https://flaskavel.com" target="_blank"><img src="https://raw.githubusercontent.com/flaskavel/framework/refs/heads/master/flaskavel/art/logo.png" width="505"></a></p>

Welcome to **Flaskavel**, the web framework designed to provide a seamless and powerful development experience! If you're looking for a solution that combines elegance, robustness, and ease of use, you're in the right place.

---

## **What is Flaskavel?**

Flaskavel is not just another Python framework—it's a unique web development environment built with the ideology of **Laravel** and the lightweight nature of **Flask**. We've crafted Flaskavel to make web development as intuitive as possible while maintaining the power and scalability you need for modern applications.

### **A Blend of Flask and Laravel Ideologies**

While **Flaskavel** might bear the name **Flask**, don't be mistaken—Flask is only used to handle HTTP requests. Beyond that, Flaskavel is entirely developed by our team. From routing and error handling to server initialization and even the built-in **Bootstrap**, everything is crafted by the Flaskavel team to give you complete control and flexibility.

As for **Laravel**—while we don't directly implement Laravel, we embrace its **philosophy** and **structure**. We took the best practices and architecture from Laravel, and merged it with Flask's simplicity, so that any Laravel developer can easily transition to Flaskavel. In our introduction, we dive deeper into why this beautiful solution came into existence.

---

## **Why Flaskavel?**

At Flaskavel, we understand that developers seek a framework that doesn't just work but also evolves with the changing landscape of web development. Here's why Flaskavel stands out:

### **Progressive and Feature-Rich**
Flaskavel was built to progressively cover everything you can accomplish in other languages but with Python's strength. 

- **Create REST APIs effortlessly**: With Flaskavel, creating RESTful APIs is a breeze, and it comes with the flexibility you need for modern, scalable services.
- **Render content with SSR**: Looking for Server-Side Rendering (SSR)? Flaskavel allows you to render dynamic content directly on the server and serve it to the browser—faster and more efficiently.
- **Powerful Console System**: Need to build a powerful command-line interface? Flaskavel makes it easier than ever to create sophisticated console commands. Plus, you'll have access to features like AI, OCR, and more without the overhead that other languages impose.
- **Native Desktop Systems (Coming Soon!)**: You’ve heard of “Native” applications before, but what’s more native than Python? Flaskavel can be used to build highly efficient desktop systems, providing a true native experience across platforms.
- **Mobile Applications (Coming Soon!)**: While we focus on the web for now, we're already working on extending Flaskavel to support mobile app development. The future holds incredible possibilities!

---

## **A Framework with Endless Possibilities**

### **A Framework for All Developers**

Whether you're an experienced developer or just starting, Flaskavel is designed to be approachable and powerful. If you’re familiar with Laravel, Flaskavel will feel like a natural fit. Its clear structure, elegant syntax, and robust features make Flaskavel a framework you can rely on for any project—small or large.

### **The Flaskavel Community**

One of the core values of Flaskavel is **community**. As we continue to grow and improve, Flaskavel thrives on collaboration. By joining our community, you’ll unlock endless opportunities, share knowledge, and contribute to making Flaskavel even better. The more you contribute, the faster we evolve!

---

## **Features**

- **Lightweight and Fast**: Flaskavel inherits Flask’s minimalism and speed, allowing you to focus on the application rather than dealing with framework bloat.
- **Elegant Syntax**: Inspired by Laravel’s clean and easy-to-understand syntax, Flaskavel ensures that writing code is as enjoyable as it is productive.
- **Robust Error Handling**: Our custom error handling system ensures that you're always in control, providing clear and concise error messages.
- **Seamless Routing**: Define routes the easy way, with Flaskavel’s innovative approach to routing that’s clean, efficient, and intuitive.
- **Powerful Command-Line Interface (CLI)**: Create custom commands, manage your application, and access advanced tools right from the terminal.

---

Tienes razón, antes de activar el entorno virtual, se debe acceder a la carpeta del proyecto. Aquí está la versión corregida y mejorada con ese detalle:

---

### 1. **Install Flaskavel Globally (Not in a Virtual Environment)**:
To install Flaskavel globally on your system, use the following command:

```bash
pip install flaskavel
```

This will install Flaskavel globally, making it available for all your Python projects. If you're on macOS or Linux, you may need to prepend the command with `sudo` to grant administrator permissions:

```bash
sudo pip install flaskavel
```

If you're using Python 3, ensure you're using `pip3` instead of `pip`:

```bash
sudo pip3 install flaskavel
```

### 2. **Create Your First Flaskavel Project**:
Once Flaskavel is installed, create a new project by running:

```bash
flaskavel new example_app
```

This will generate a new project directory called `example_app` with the necessary files to get started.

### 3. **Navigate to Your Project Folder**:
Before activating the virtual environment, navigate to the folder where your project was created. Use the following command:

```bash
cd example_app
```

### 4. **Activate Flaskavel's Virtual Environment**:
Flaskavel creates a virtual environment within the project directory to keep dependencies isolated. Now that you're inside your project folder, activate the virtual environment:

- On **macOS/Linux**:

  ```bash
  source venv/bin/activate
  ```

- On **Windows**:

  ```bash
  venv\Scripts\activate
  ```

Once activated, your terminal will show the virtual environment's name (e.g., `(venv)`) indicating that you're now working within the isolated environment.

### 5. **Run Your Development Server**:
With the virtual environment activated, you can now start the Flaskavel development server:

```bash
python reactor serve
```

This will launch the server, allowing you to view your application in the browser and start developing.

---

## **Contributing**

Flaskavel is an open-source project, and we invite you to help make it better! Whether you're fixing bugs, adding new features, or simply improving the documentation, your contributions are welcome.

- **Fork the repository**
- **Create a new branch**
- **Submit a pull request**

---

## **Documentation**

For a complete reference on how to use Flaskavel, including advanced configuration and tips on building larger applications, visit our [full documentation](https://flaskavel.com).

---

## **Get Involved**

Flaskavel is all about community, so we encourage you to join us and help shape its future. You can get involved by:

- **Using Flaskavel**: Build amazing projects with it and share your experience.
- **Reporting Issues**: Found a bug? Let us know, and we’ll work on fixing it.
- **Contributing Code**: Help improve Flaskavel by submitting your own changes or features.

---

## **Conclusion**

At Flaskavel, we believe in empowering developers to create beautiful, scalable, and efficient web applications. Whether you're building APIs, SSR apps, or console tools, Flaskavel is here to provide the foundation you need. Join us today and be a part of this exciting new development revolution!
